outerShadowOpacity property
Opacity of the soft outer shadow lifting the droplet off the background. Rendered by the wrapping widget, not the shader. Set to 0 to render flat.
Implementation
final double outerShadowOpacity;
Opacity of the soft outer shadow lifting the droplet off the background. Rendered by the wrapping widget, not the shader. Set to 0 to render flat.
final double outerShadowOpacity;