GlassDialogAction class
Action shown in a GlassDialog.
Constructors
- GlassDialogAction({required String label, required VoidCallback onPressed, GlassButtonVariant variant = GlassButtonVariant.secondary})
-
Creates a dialog action.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Button label.
final
- onPressed → VoidCallback
-
Tap handler (typically calls
Navigator.popwith a value).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → GlassButtonVariant
-
Visual variant for the action button.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited